Median Fluorescent Intensity (MFI) to Relative Antibody Units (RAU) conversion for Pk proteins
Source:R/MFItoRAU.R
MFItoRAU_Pk.RdThis function is utilised in the master function `MFItoRAU_Plasmo()`.

R/MFItoRAU.R
MFItoRAU_Pk.RdThis function is utilised in the master function `MFItoRAU_Plasmo()`.