This function checks the platform the user has input and whether it aligns with the correct format as expected. Will report error if NOT aligned.
Examples
your_raw_data <- system.file("extdata", "example_MAGPIX_plate1.csv", package = "SeroTrackR")
.check_platform(raw_data = your_raw_data, platform = "magpix")
#> [1] TRUE