A short function to obtain the github version from the repository. This is a generalisable function that can be used for any version tags on a repo.
A short function to obtain the github version from the repository. This is a generalisable function that can be used for any version tags on a repo.